@@ -330,8 +330,11 @@ class Dataset(DatasetMeta):
             "task_type": "shared_links",
         }
         if export_path:
-            export_path = self._x_api.get_dataset_path(self._id, export_path)
-            post_data["export_path"] = f"[{','.join(export_path)}]"
+            if isinstance(export_path, list):
+                path = [self._x_api.get_dataset_path(self._id, path) for path in export_path]
+                post_data["export_path"] = path
+            else:
+                raise InvalidParamsError(message=f"export_path value type should be list")
 
         self._x_api.post_export(self._id, post_data)
         print("export data start, please wait...")
