@@ -25,7 +25,7 @@ if __name__ == '__main__':
     dataset.summary()
 
     # import directory and save data to external cloud storage
-    dataset.import_data("import_test/sample_test", storage_type="external")
+    dataset.import_data("import_test/sample_test", storage_type="cos")
     dataset.summary()
 
     # create a new version and inherit data from a previous version
